# pyNCS

A Python NoCopyrightSounds "API" wrapper written with asyncio.

## This isn't actually an API wrapper
This module just parses NCS' HTML page, because NCS does not have public APIs (at least not yet).